==> tuia-news-center-api-2.5.8.0-20190828.073052-4-sources.jar: cn/com/duiba/tuia/news/center/dto/treeRewardConfig/TreeRewardConfigDto.java <==
package cn.com.duiba.tuia.news.center.dto.treeRewardConfig;

import java.io.Serializable;
import java.util.Date;

public class TreeRewardConfigDto implements Serializable{
    private Long id;

    private String configVersion;

    private Integer configStatus;

    private String configContent;

    private Integer doubleType;

    private String jumpUrl;

    private String slotId;

    private Date gmtCreate;

    private Date gmtModified;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getConfigVersion() {
        return configVersion;
    }

    public void setConfigVersion(String configVersion) {
        this.configVersion = configVersion == null ? null : configVersion.trim();
    }

    public Integer getConfigStatus() {
        return configStatus;
    }

    public void setConfigStatus(Integer configStatus) {
        this.configStatus = configStatus;
    }

    public String getConfigContent() {
        return configContent;
    }

    public void setConfigContent(String configContent) {
        this.configContent = configContent == null ? null : configContent.trim();
    }

    public Integer getDoubleType() {
        return doubleType;
    }

    public void setDoubleType(Integer doubleType) {
        this.doubleType = doubleType;
    }

    public String getJumpUrl() {
        return jumpUrl;
    }

    public void setJumpUrl(String jumpUrl) {
        this.jumpUrl = jumpUrl == null ? null : jumpUrl.trim();
    }

    public String getSlotId() {
        return slotId;
    }

    public void setSlotId(String slotId) {
        this.slotId = slotId == null ? null : slotId.trim();
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}

==> tuia-news-center-api-2.9.0.0-20191014.075526-1-sources.jar: cn/com/duiba/tuia/news/center/dto/treeRewardConfig/TreeRewardConfigDto.java <==
package cn.com.duiba.tuia.news.center.dto.treeRewardConfig;

import java.io.Serializable;
import java.util.Date;

public class TreeRewardConfigDto implements Serializable{
    private Long id;

    private String configVersion;

    private Integer configStatus;

    private String coinConfigContent;

    private String boxConfigContent;

    private String jumpUrl;

    private String slotId;

    private Date gmtCreate;

    private Date gmtModified;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getConfigVersion() {
        return configVersion;
    }

    public void setConfigVersion(String configVersion) {
        this.configVersion = configVersion == null ? null : configVersion.trim();
    }

    public Integer getConfigStatus() {
        return configStatus;
    }

    public void setConfigStatus(Integer configStatus) {
        this.configStatus = configStatus;
    }

    public String getCoinConfigContent() {
        return coinConfigContent;
    }

    public void setCoinConfigContent(String coinConfigContent) {
        this.coinConfigContent = coinConfigContent == null ? null : coinConfigContent.trim();
    }

    public String getBoxConfigContent() {
        return boxConfigContent;
    }

    public void setBoxConfigContent(String boxConfigContent) {
        this.boxConfigContent = boxConfigContent == null ? null : boxConfigContent.trim();
    }

    public String getJumpUrl() {
        return jumpUrl;
    }

    public void setJumpUrl(String jumpUrl) {
        this.jumpUrl = jumpUrl == null ? null : jumpUrl.trim();
    }

    public String getSlotId() {
        return slotId;
    }

    public void setSlotId(String slotId) {
        this.slotId = slotId == null ? null : slotId.trim();
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}
